    //
//  EAGLViewController.m
//  Snake
//
//  Created by Vahid Kazemi on 7/13/10.
//  Copyright 2010 KTH. All rights reserved.
//

#import "EAGLViewController.h"
#import "EAGLView.h"
#import "World.h"

static EAGLViewController* theEAGLVC = nil;

@implementation EAGLViewController

@synthesize tfPoints;
@synthesize tfRank;
@synthesize btnStatus;
@synthesize btnPlay;
@synthesize btnRestart;
@synthesize btnOF;
@synthesize btnWorld;
@synthesize btnPanel;
@synthesize accelerometer;

- (void)pause: (id)sender
{
	[[World getInstance] toggleGameState];
}

- (void)play: (id)sender
{
	[[World getInstance] toggleGameState];
}

- (void)reset: (id)sender
{
	[[World getInstance] start];
}

- (void)showOF: (id)sender
{
}

- (void)showGames:(id)sender
{
}


-(void)playhaven:(UIView *)view didLoadWithContext:(id)contextValue {
	[[self view] addSubview:view];
}

-(void)playhaven:(UIView *)view didFailWithError:(NSString *)message context:(id)contextValue {
	//NSLog(@"playhaven didFailWithError: %@", message);
	[view removeFromSuperview];
}

-(void)playhaven:(UIView *)view wasDismissedWithContext:(id)contextValue {
	[view removeFromSuperview];
}

- (IBAction) touchesBegan: (NSSet*)touches withEvent:(UIEvent*)event
{	
	if([[World getInstance] isPaused] || [[World getInstance] isStopped]){
		[self pause:nil];
	}
	
	UITouch* touch = [touches anyObject];
	touchStartPos = [touch locationInView:self.view];
}

- (IBAction) touchesEnded: (NSSet*)touches withEvent:(UIEvent*)event
{	
	UITouch* touch = [touches anyObject];
	CGPoint touchCurrentPos = [touch locationInView:self.view];
	
	CGFloat deltaX = touchCurrentPos.x - touchStartPos.x;
	CGFloat deltaY = touchCurrentPos.y - touchStartPos.y;
	
	if(MAX(fabs(deltaX), fabs(deltaY))>1){
		if(fabs(deltaX)>fabs(deltaY)){
			if(deltaX>0){
				[[World getInstance] control:kDirRight];
			}
			else{
				[[World getInstance] control:kDirLeft];
			}
		}
		else{
			if(deltaY>0){
				[[World getInstance] control:kDirDown];
			}
			else{
				[[World getInstance] control:kDirUp];
			}
		}
	}
}

- (void)accelerometer:(UIAccelerometer *)accelerometer didAccelerate:(UIAcceleration *)acceleration
{
	[[(EAGLView*)[self view] getRenderer] accelerate:acceleration];
}

- (void) showOptions
{
	btnPlay.hidden = NO;
	btnRestart.hidden = NO;
	btnOF.hidden = NO;
	btnWorld.hidden = NO;
	btnPanel.hidden = NO;
}

- (void) hideOptions
{
	btnPlay.hidden = YES;
	btnRestart.hidden = YES;
	btnOF.hidden = YES;
	btnWorld.hidden = YES;
	btnPanel.hidden = YES;
}

- (void) update
{		
	int points = [[World getInstance] getPoints];
	int rank = [World calculateRank:points];
	
	static int lastRankCount = 0;
	if(curRank!=rank){
		curRank = rank;
		[tfRank setText:([World getRankTitle:rank])];
		[[[World getInstance] getSoundMgr] play:kSoundSnake+rank];
		if(rank > 0){
			//[OFAchievementService unlockAchievement:[World getAchivementID:rank] onSuccess:OFDelegate()	onFailure:OFDelegate()];
		}
		lastRankCount = 50;
	}
	
	if(lastRankCount>0){
		if(lastRankCount>1){
			[tfRank setTextColor:[UIColor colorWithWhite:1 alpha:sinf(lastRankCount*0.5f)]];		
		}
		else{
			[tfRank setTextColor:[UIColor colorWithWhite:1 alpha:0.7f]];
		}
		lastRankCount--;
	}
	
	if(curPoints!=points){
		if(curPoints >= points){
			curPoints = points;
		}
		else{
			curPoints += MIN(MAX(5, (points-curPoints)/2), (points-curPoints));
		}
		[tfPoints setText:[NSString stringWithFormat:@"%d pts", curPoints]];
	}
	
	if([[World getInstance] isStopped]){
		if(!lastGameStopState){
			[btnStatus setImage:[UIImage imageNamed:@"reset.png"] forState:UIControlStateNormal];
			[self showOptions];
			lastGameStopState = true;
			//[OFHighScoreService setHighScore:points forLeaderboard:@"442224" onSuccess:OFDelegate() onFailure:OFDelegate()];
		}
	}
	else{
		if([[World getInstance] isPaused]){
			if(!lastGamePauseState || lastGameStopState){
				[btnStatus setImage:[UIImage imageNamed:@"play.png"] forState:UIControlStateNormal];
				lastGamePauseState = true;
				[self showOptions];
			}
		}
		else{
			if(lastGamePauseState || lastGameStopState){
				[btnStatus setImage:[UIImage imageNamed:@"pause.png"] forState:UIControlStateNormal];
				lastGamePauseState = false;
				[self hideOptions];
			}
		}
		lastGameStopState = false;
	}
}

// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
	
    [super viewDidLoad];
	[(EAGLView*)[self view] startAnimation];
	theEAGLVC = self;
	
	World* world = [World getInstance];
	curPoints = [world getPoints];
	curRank = [World calculateRank:curPoints];
	touchStartPos.x = touchStartPos.y = 0;
	
	lastGameStopState = [world isStopped];
	lastGamePauseState = [world isPaused];
	
	// setup acclerometer
	accelerometer = [UIAccelerometer sharedAccelerometer];
	accelerometer.updateInterval = .1;
	accelerometer.delegate = self;
	
	[NSTimer scheduledTimerWithTimeInterval:0.1f 
									 target:self 
								   selector:@selector(update) 
								   userInfo:nil 
									repeats:YES];
}

/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

- (void)didReceiveMemoryWarning {
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	//[btnStatus setImage:nil forState:UIControlStateNormal];
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}


- (void)dealloc {
    [super dealloc];
}


@end
