//
//  World.h
//  Snake
//
//  Created by Vahid Kazemi on 7/13/10.
//  Copyright 2010 KTH. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "Vector.h"
#import "Snake.h"
#import "SoundMgr.h"

#define kNumColors 7
#define kNumRotations 4
#define kBoardWidth 12
#define kBoardHeight 20

typedef enum {
	kBlockEmpty,
	kBlockRock,
	kBlockFood,
	kBlockSnake,
	kBlockSnakeEnd=kBlockSnake+64
} BlockType;

@interface World : NSObject {
	SoundMgr* soundMgr;
	BlockType board[kBoardWidth*kBoardHeight];
	NSMutableArray* snakes;
	Snake* player;
	int playerDir;
	Vector2i food;
	float points;
	bool gamePaused;
	bool gameStoped;
}

// return singleton object
+ (World*) getInstance;
+ (void) releaseInstance;

+ (int) calculateRank:(int) points;
+ (NSString*) getRankTitle: (int) rank;
+ (NSString*) getAchivementID: (int) rank;

// input functions
- (void) start;
- (void) stop;
- (void) toggleGameState;
- (void) control:(int)dir;

- (void) move: (Snake*)Snake;
- (bool) turn: (Snake*)Snake To:(int)dir;

- (void) update;

- (int) getPoints;
- (NSMutableArray*) getSnakes;
- (Snake*) getPlayer;
- (BlockType*) getBoard;
- (bool) isPaused;
- (bool) isStopped;
- (SoundMgr*) getSoundMgr;

@end
